@@ -84,6 +84,12 @@ class League(BaseLeague):
             positional_ratings[pos] = teams_rating
         return positional_ratings
 
+    def refresh(self):
+        '''Gets latest league data. This can be used instead of creating a new League class each week'''
+        data = super()._fetch_league()
+
+        self.nfl_week = data['status']['latestScoringPeriod']
+        self._fetch_teams(data)
     def load_roster_week(self, week: int) -> None:
         '''Sets Teams Roster for a Certain Week'''
         params = {
@@ -221,9 +227,9 @@ class League(BaseLeague):
                               reverse=False)
 
         for team in teams_sorted:
-            wins = [0]*32
+            wins = [0]*len(teams_sorted) 
             for mov, opponent in zip(team.mov[:week], team.schedule[:week]):
-                opp = int(opponent.team_id)-1
+                opp = teams_sorted.index(opponent)
                 if mov > 0:
                     wins[opp] += 1
             win_matrix.append(wins)
